# Nextmv Python SDK

Welcome to `nextmv`, the general Python SDK for the Nextmv Platform. To learn
more about `nextmv`, visit the [docs][docs].

## Installation

Requires Python `>=3.9`. Install using `pip`:

```bash
pip install nextmv
```

Install all optional dependencies (recommended):

```bash
pip install "nextmv[all]"
```

[docs]: https://nextmv.io/docs/python-sdks/nextmv/installation
